# Tkns

Easy to use generator of custom size tokens

## Instalation

using [pip](https://pip.pypa.io/en/stable/quickstart/)

```console
pip install -U tkns
```

## A Simple Example

```python
import tkns

token = tkns.token()

token = tkns.tokenRandom()

randomString = tkns.randomLetters()
```
